# Changelog

## v0.0.5 (2024-11-10)

#### Fixes

* Adding some data cleanup routines.

Full set of changes: [`v0.0.4...v0.0.5`](https://github.com/kev-m/pyFitOut/compare/v0.0.4...v0.0.5)

## v0.0.4 (2024-11-10)

#### Fixes

* Improving detectin of JSON files for resting heart rate.

Full set of changes: [`v0.0.3...v0.0.4`](https://github.com/kev-m/pyFitOut/compare/v0.0.3...v0.0.4)

## v0.0.3 (2024-11-09)

#### Fixes

* Various bug fixes

Full set of changes: [`v0.0.2...v0.0.3`](https://github.com/kev-m/pyFitOut/compare/v0.0.2...v0.0.3)

## v0.0.2 (2024-11-09)

#### Fixes

* Fixing instructions.

Full set of changes: [`v0.0.1...v0.0.2`](https://github.com/kev-m/pyFitOut/compare/v0.0.1...v0.0.2)

## v0.0.1 (2024-11-09)

#### Fixes

* Initial commit.
